# ifndef yyMakeInterface
# define yyMakeInterface

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeInterface_Exit) ARGS ((void));

extern void MakeInterface ARGS ((tTree t));

extern void BeginMakeInterface ARGS ((void));
extern void CloseMakeInterface ARGS ((void));

# endif
